@@ -101,9 +101,7 @@ pub fn receiver(
     use_pinned_memory: bool,
 ) -> JoinHandle<()> {
     let res = sock.set_read_timeout(Some(Duration::new(1, 0)));
-    if res.is_err() {
-        panic!("streamer::receiver set_read_timeout error");
-    }
+    assert!(!res.is_err(), "streamer::receiver set_read_timeout error");
     let exit = exit.clone();
     Builder::new()
         .name("solana-receiver".to_string())
@@ -132,7 +130,9 @@ fn recv_send(
     Ok(())
 }
 
-pub fn recv_batch(recvr: &PacketBatchReceiver) -> Result<(Vec<PacketBatch>, usize, u64)> {
+pub fn recv_packet_batches(
+    recvr: &PacketBatchReceiver,
+) -> Result<(Vec<PacketBatch>, usize, Duration)> {
     let timer = Duration::new(1, 0);
     let packet_batch = recvr.recv_timeout(timer)?;
     let recv_start = Instant::now();
@@ -150,11 +150,7 @@ pub fn recv_batch(recvr: &PacketBatchReceiver) -> Result<(Vec<PacketBatch>, usiz
         packet_batches.len(),
         num_packets
     );
-    Ok((
-        packet_batches,
-        num_packets,
-        solana_sdk::timing::duration_as_ms(&recv_duration),
-    ))
+    Ok((packet_batches, num_packets, recv_duration))
 }
 
 pub fn responder(
